import { isInternal } from '../../util/path.js';
import { timerify } from '../../util/Performance.js';
import { hasDependency, load } from '../../util/plugin.js';
import { toEntryPattern } from '../../util/protocols.js';
import { isConfigurationOutput } from './types.js';
export const NAME = 'GraphQL Codegen';
export const ENABLERS = [/^@graphql-codegen\//];
export const PACKAGE_JSON_PATH = 'codegen';
export const isEnabled = ({ dependencies }) => hasDependency(dependencies, ENABLERS);
export const CONFIG_FILE_PATTERNS = [
    'codegen.{json,yml,yaml,js,ts,mjs,cts}',
    '.codegenrc.{json,yml,yaml,js,ts}',
    'codegen.config.js',
    'package.json',
];
const findPluginDependencies = async (configFilePath, options) => {
    const { manifest, isProduction } = options;
    if (isProduction)
        return [];
    const localConfig = configFilePath.endsWith('package.json')
        ? manifest[PACKAGE_JSON_PATH]
        : await load(configFilePath);
    if (!localConfig)
        return [];
    const generateSet = Object.values(localConfig.generates);
    const configurationOutput = generateSet.filter(isConfigurationOutput);
    const presets = configurationOutput
        .map(configOutput => (configOutput.preset ? configOutput.preset : undefined))
        .filter((preset) => typeof preset === 'string')
        .map(presetName => `@graphql-codegen/${presetName}${presetName.endsWith('-preset') ? '' : '-preset'}`);
    const flatPlugins = generateSet
        .filter((config) => !isConfigurationOutput(config))
        .flatMap(item => Object.keys(item))
        .map(plugin => `@graphql-codegen/${plugin}`);
    const nestedPlugins = configurationOutput
        .flatMap(configOutput => (configOutput.plugins ? configOutput.plugins : []))
        .flatMap(plugin => {
        if (typeof plugin !== 'string')
            return [];
        if (isInternal(plugin))
            return [toEntryPattern(plugin)];
        return [`@graphql-codegen/${plugin}`];
    });
    return [...presets, ...flatPlugins, ...nestedPlugins];
};
export const findDependencies = timerify(findPluginDependencies);
