import { timerify } from '../../util/Performance.js';
import { hasDependency, load } from '../../util/plugin.js';
export const NAME = 'Remark';
export const ENABLERS = ['remark-cli'];
export const PACKAGE_JSON_PATH = 'remarkConfig';
export const isEnabled = ({ dependencies }) => hasDependency(dependencies, ENABLERS);
export const CONFIG_FILE_PATTERNS = [
    'package.json',
    '.remarkrc',
    '.remarkrc.json',
    '.remarkrc.{js,cjs,mjs}',
    '.remarkrc.{yml,yaml}',
];
const findRemarkDependencies = async (configFilePath, options) => {
    const { manifest, isProduction } = options;
    if (isProduction)
        return [];
    const localConfig = configFilePath.endsWith('package.json')
        ? manifest[PACKAGE_JSON_PATH]
        : await load(configFilePath);
    if (!localConfig)
        return [];
    const plugins = localConfig.plugins
        ?.flatMap(plugin => {
        if (typeof plugin === 'string')
            return plugin;
        if (Array.isArray(plugin) && typeof plugin[0] === 'string')
            return plugin[0];
        return [];
    })
        .map(plugin => (plugin.startsWith('remark-') ? plugin : `remark-${plugin}`)) ?? [];
    return plugins;
};
export const findDependencies = timerify(findRemarkDependencies);
